Bead, acrylic, multicolored, 32mm double-sided flat round with rainbow swirl design and 1.75mm hole. Sold per pkg of 6. - Fire Mountain Gems and Beads
Description: An affordable alternative to glass beads, the lightweight acrylic double-sided flat round beads feature a colorful rainbow swirl design. Colors can include red, orange, yellow, green, blue and more.

- 800-355-2137

- Login
- Create Account
- Favorites List

Close
Email:
Password:
Remember Me
Forgot Your Password? Need Help?
? If you are still having trouble signing in, click here.
0 items
Home
Deal of the Day FREE Catalog
Browse

### Selected Refinements

- Category: Beads Remove
- Material: Acrylic Remove
- Color: Multicolored Remove
- Shape: Flat Round/Coin Remove
- Stringing Length: 25mm & Up Remove

Beads / Acrylic / Multicolored / Flat Round/Coin / 25mm & Up / H20-6447PB

# Bead, acrylic, multicolored, 32mm double-sided flat round with rainbow swirl design and 1.75mm hole. Sold per pkg of 6.

As Low As $0.24 per bead

1 - 14 | 15 - 49 | 50 - 99 | 100+
--- | --- | --- | ---
$3.46 | $2.49 | $1.71 | $1.44

- IN STOCK -

All products (except FREE items) apply to your discount level.
More Details.

Add to Favorites

## Item Number: H20-6447PB Have a question about this item?

An affordable alternative to glass beads, the lightweight acrylic double-sided flat round beads feature a colorful rainbow swirl design. Colors can include red, orange, yellow, green, blue and more.

You May Also Like...
Regular Stock
-
Bead, acrylic, multicolored, 32mm double-sided flat round with circular design and 1.75mm hole. Sold per pkg of 6.
Mix and Match for the Best Prices

1 - 14 | 15 - 49 | 50 - 99 | 100+
--- | --- | --- | ---
$3.63 | $2.61 | $1.76 | $1.47

As Low As
$0.25
per bead
H20-6446PB
- IN STOCK -
H20-6446PB
Add to Favorites
---
Regular Stock
-
Bead, acrylic, multicolored, 32mm double-sided flat round with circular design and 1.75mm hole. Sold per pkg of 6.
Mix and Match for the Best Prices

1 - 14 | 15 - 49 | 50 - 99 | 100+
--- | --- | --- | ---
$3.63 | $2.61 | $1.76 | $1.47

As Low As
$0.25
per bead
H20-6445PB
- IN STOCK -
H20-6445PB
Add to Favorites
---
Limited Quantity
-
Bead, acrylic, multicolored, 32mm double-sided flat round with flower design and 1.75mm hole. Sold per pkg of 6.
SAVE
Regular Price:
72%
$3.68
Sale Price:
$1.00
H20-6459PB
- IN STOCK -
(Only 95 available)
H20-6459PB
Add to Favorites
---
Regular Stock
-
Bead, polymer clay / glass rhinestone / antiqued brass-finished "pewter" ... Sold per 3-piece set.
Mix and Match for the Best Prices

1 - 14 | 15 - 49 | 50 - 99 | 100+
--- | --- | --- | ---
$6.63 | $4.67 | $3.44 | $2.90

As Low As
$0.97
per bead
H20-A2457MB
- IN STOCK -
H20-A2457MB
Add to Favorites
---
Regular Stock
-
Bead, polymer clay / glass rhinestone / antiqued brass-finished "pewter" ... Sold per 3-piece set.
Mix and Match for the Best Prices

1 - 14 | 15 - 49 | 50 - 99 | 100+
--- | --- | --- | ---
$6.63 | $4.67 | $3.44 | $2.90

As Low As
$0.97
per bead
H20-A2458MB
- IN STOCK -
H20-A2458MB
Add to Favorites
---
Regular Stock
-
Bead, acrylic, black/brown/white, 32mm double-sided flat round with leopard pattern and 1.75mm hole. Sold per pkg of 6.
Mix and Match for the Best Prices

1 - 14 | 15 - 49 | 50 - 99 | 100+
--- | --- | --- | ---
$3.46 | $2.49 | $1.71 | $1.44

As Low As
$0.24
per bead
H20-6440PB
- IN STOCK -
H20-6440PB
Add to Favorites
---
Regular Stock
-
Bead, acrylic, black and white, 32mm double-sided flat round with zebra pattern and 1.75mm hole. Sold per pkg of 6.
Mix and Match for the Best Prices

1 - 14 | 15 - 49 | 50 - 99 | 100+
--- | --- | --- | ---
$3.46 | $2.49 | $1.71 | $1.44

As Low As
$0.24
per bead
H20-6438PB
- IN STOCK -
H20-6438PB
Add to Favorites
---
Regular Stock
-
Bead, acrylic, multicolored, 32mm double-sided flat round with leopard pattern and 1.75mm hole. Sold per pkg of 6.
Mix and Match for the Best Prices

1 - 14 | 15 - 49 | 50 - 99 | 100+
--- | --- | --- | ---
$3.63 | $2.61 | $1.76 | $1.47

As Low As
$0.25
per bead
H20-6442PB
- IN STOCK -
H20-6442PB
Add to Favorites
---
Regular Stock
-
Bead, acrylic, multicolored, 32mm double-sided flat round with tree design and 1.75mm hole. Sold per pkg of 6.
Mix and Match for the Best Prices

1 - 14 | 15 - 49 | 50 - 99 | 100+
--- | --- | --- | ---
$3.63 | $2.61 | $1.76 | $1.47

As Low As
$0.25
per bead
H20-6454PB
- IN STOCK -
H20-6454PB
Add to Favorites
---
Limited Quantity
-
Bead, acrylic, black and white, 32mm double-sided flat round with Dalmatian pattern and 1.75mm hole. Sold per pkg of 6.
SAVE
Regular Price:
72%
$3.68
Sale Price:
$1.00
H20-6439PB
- IN STOCK -
(Only 84 available)
H20-6439PB
Add to Favorites
---

Not what you're looking for? See all Beads

#### Discount Level

0

Add 0 units of any item to reach your next break.

View details